@@ -18,11 +18,6 @@ describe Facts::Linux::Sshalgorithmkey do
         receive(:resolve).with(:ssh).and_return(ssh)
     end
 
-    it 'calls Facter::Resolvers::Ssh' do
-      fact.call_the_resolver
-      expect(Facter::Resolvers::Ssh).to have_received(:resolve).with(:ssh)
-    end
-
     it 'returns a list of resolved facts' do
       expect(fact.call_the_resolver).to be_an_instance_of(Array).and \
         contain_exactly(an_object_having_attributes(name: "ssh#{legacy_fact1[:name]}key", value: legacy_fact1[:value]),
